<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>StartPage</name>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
      <source>Start</source>
      <translation>Hasi</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
      <source>Documents</source>
      <translation>Dokumentuak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
      <source>Help</source>
      <translation>Laguntza</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
      <source>Activity</source>
      <translation>Jarduera</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
      <source>Recent files</source>
      <translation>Azken fitxategiak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
      <source>Tip</source>
      <translation>Aholkua</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
      <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
      <translation>Egokitu hemen erakutsiko diren azken fitxategiak 'Editatu -&gt; Hobespenak -&gt; Orokorra -&gt; Azken fitxategien zerrendaren luzera' menuan</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
      <source>Examples</source>
      <translation>Adibideak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
      <source>General documentation</source>
      <translation>Dokumentazio orokorra</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
      <source>User hub</source>
      <translation>Erabiltzaileen gunea</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
      <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
      <translation>Atal honek FreeCAD erabiltzaile orokorrentzako dokumentazio erabilgarria du: lan-mahai guztien zerrenda bat, FreeCAD aplikazioa instalatu eta erabiltzeko argibide xeheak, tutorialak, eta lanean hasteko behar duzun guztia.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
      <source>Power users hub</source>
      <translation>Erabiltzaile aurreratuen gunea</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
      <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
      <translation>Atal honek erabiltzaile aurreratuentzako eta Python scriptak idazteko interesa duten pertsonentzako dokumentazioa biltzen du. Horrez gain, makroen biltegi bat, haiek instalatu eta erabiltzeko argibideak eta FreeCADek zure beharrak bete ditzan pertsonalizatzeko informazio gehiago duzu.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>Developers hub</source>
      <translation>Garatzaileen gunea</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
      <translation>Atal honek garatzaileentzako materiala du: Nola konpilatu FreeCAD, nola dagoen FreeCAD iturburu-kodea egituratuta eta nola arakatu kode hori, nola garatu lan-mahai berriak eta nola kapsulatu FreeCAD zuk garatutako beste aplikazioren batean.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
      <source>Manual</source>
      <translation>Eskuliburua</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
      <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
      <translation>FreeCAD eskuliburua wiki horretan dagoen informazio aurkezteko beste modu bat da. Liburu bat bailitzan irakurtzeko moduan prestatuta dago, eta goiko guneetako beste orri batzuetarako sarrera emango dizu. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;Bertsio elektronikoak&lt;/a&gt; ere eskuragarri daude.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
      <source>Workbenches documentation</source>
      <translation>Lan-mahaien dokumentazioa</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
      <source>These are the help pages of all the workbenches currently installed on this computer.</source>
      <translation>Ordenagailu honetan instalatutako lan-mahai guztien laguntza-orriak dira hauek.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
      <source>Getting help from the community</source>
      <translation>Eskuratu komunitatearen laguntza</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
      <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
      <translation>&lt;a href="http://forum.freecadweb.org"&gt;FreeCAD foroa&lt;/a&gt; leku ona da FreeCADen beste erabiltzaile batzuek eta garatzaileen laguntza jasotzeko. Foroak atal desberdinak ditu arazo eta eztabaida mota askotarikoak bideratzeko. Zalantzarik baduzu, argitaratu zure mezuak &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; atal orokorrean.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
      <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
      <translation>Foroan zerbait idazten duzun lehen aldia da, ziurtatu &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;gidalerroak irakurri dituzula&lt;/a&gt;!</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
      <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
      <translation>FreeCADek &lt;a href="https://www.freecadweb.org/tracker"&gt;akatsen zerrenda&lt;/a&gt; publiko bat dauka. Edozeinek bidali ditzake akatsak eta eginbide berriak proposatu. Gehiegizko lana sortzea saihesteko eta zure akatsa konpondua izan dadin aukera gehiago izateko, mesedez irakurri &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;akatsak bidaltzeko gida&lt;/a&gt; ezer bidali baino lehenago.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
      <source>Available addons</source>
      <translation>Gehigarri erabilgarriak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
      <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
      <translation>Behean zure FreeCAD instalazioari gehitu ahal zaizkion beste lan-mahai batzuk zerrendatu dira. Arakatu eta instalatu lan-mahai horiek 'Tresnak -&gt; Gehigarrien kudeatzailea' erabilita. Haiei buruzko informazio gehiago eskura dezakezu beheko esteketan klik eginda.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
      <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
      <translation>Zure FreeCAD bertsioarekin paketatuta ez badator, instalatu FreeCADen dokumentazio-paketea Interneterako konexiorik ez duzunean dokumentazio-guneak, lan-mahaien laguntza eta banakako komandoen dokumentazioa kontsultatu ahal izateko.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
      <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
      <translation>Ezin izan da informazioa atzitu GitHub gunetik. &lt;a href="EnableDownload.py"&gt;Baimendu FreeCADi Internetera sartzen&lt;/a&gt; eta birkargatu hasierako orria.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
      <source>Recent commits</source>
      <translation>Azken aldaketak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
      <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
      <translation>Behean &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCADen iturburu-kodeari&lt;/a&gt; gehitutako azken aldaketak ikus daitezke. Aldaketa horiek ez dute zertan adierazi beharrik zein FreeCAD bertsioa ari zaren erabiltzen. Begiratu &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;aukera erabilgarriak&lt;/a&gt; garapen-bertsio bat eskuratu nahi baduzu.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>See all commits on github</source>
      <translation>Ikusi aldaketa guztiak github-en</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
      <translation>Karpeta pertsonalizatu bat konfiguratu daiteke hemen erakutsia izan dadin. Horretarako aukera: 'Editatu -&gt; Hobespenak -&gt; Hasiera -&gt; Erakutsi karpeta gehigarria'</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
      <source>version</source>
      <translation>bertsioa</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
      <source>build</source>
      <translation>paketea</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
      <source>Create new...</source>
      <translation>Sortu berria...</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
      <source>Unknown</source>
      <translation>Ezezaguna</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
      <source>Forum</source>
      <translation>Foroa</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
      <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
      <translation>&lt;a href="https://forum.freecadweb.org"&gt;FreeCAD foroko&lt;/a&gt; azken bidalketak:</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
      <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
      <translation>Goiko estekak zure mahaigaineko nabigatzailearekin irekitzeko, egin eskuineko klik eta hautatu 'Ireki kanpoko nabigatzailean'</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
      <source>Creation date</source>
      <translation>Sortze-data</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
      <source>Last modification</source>
      <translation>Azken aldaketa</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Notes</source>
      <translation>Oharrak</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Open start page preferences</source>
      <translation>Ireki hasiera-orriaren hobespenak</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <location filename="../../Workbench.cpp" line="65"/>
      <source>Start page</source>
      <translation>Hasierako orria</translation>
    </message>
  </context>
  <context>
    <name>CmdStartPage</name>
    <message>
      <location filename="../../Command.cpp" line="44"/>
      <source>Start</source>
      <translation>Hasi</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="45"/>
      <source>Start Page</source>
      <translation>Hasierako orria</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Displays the start page in a browser view</source>
      <translation>Hasierako orria nabigatzaile batean irekitzen du</translation>
    </message>
  </context>
  <context>
    <name>DlgStartPreferences</name>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="14"/>
      <source>Start page options</source>
      <translation>Hasierako orriaren aukerak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="20"/>
      <source>Start page template</source>
      <translation>Hasierako orriaren txantiloia</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="26"/>
      <source>An optional HTML template that will be used instead of the default start page.</source>
      <translation>Aukerako HTML txantiloi bat, hasierako orri lehenetsiaren ordez erakutsiko dena.</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="42"/>
      <source>Contents</source>
      <translation>Edukiak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="48"/>
      <source>Show forum</source>
      <translation>Erakutsi foroa</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="55"/>
      <source>Show examples folder contents</source>
      <translation>Erakutsi adibideen karpetako edukiak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="62"/>
      <source>Show additional folder</source>
      <translation>Erakutsi karpeta gehigarria</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="69"/>
      <source>If you want the examples to show on the first page</source>
      <translation>Adibideak lehen orrian erakutsi nahi badituzu</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="91"/>
      <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
      <translation>Hau markatuta badago, FreeCAD foroko azken bidalketak bistaratuko dira 'Jarduera' fitxan</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="110"/>
      <source>An optional custom folder to be displayed at the bottom of the first page</source>
      <translation>Lehen orriaren behealdean bistaratuko den aukerako karpeta pertsonalizatu bat</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="126"/>
      <source>Show notepad</source>
      <translation>Erakutsi ohar-bloka</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="133"/>
      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
      <translation>Ohar-blok bat erakusten du fitxategi-miniaturen alboan, FreeCAD saioen artean oharrak hartu ahal ditzazun</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="155"/>
      <source>Fonts and colors</source>
      <translation>Letra-tipoak eta koloreak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="167"/>
      <source>The background of the main start page area</source>
      <translation>Hasierako orriaren area nagusiaren atzeko planoa</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="187"/>
      <source>Background color</source>
      <translation>Atzeko planoaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="199"/>
      <source>in FreeCAD</source>
      <translation>FreeCADen</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="218"/>
      <source>In external browser</source>
      <translation>Kanpoko nabigatzailean</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="236"/>
      <source>Background color gradient down</source>
      <translation>Atzeko planoaren kolorearen beheranzko gradientea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="249"/>
      <source>The color of the version text</source>
      <translation>Bertsio-testuaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="269"/>
      <source>Link color</source>
      <translation>Estekatu kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="276"/>
      <source>An optional image to display as background</source>
      <translation>Atzeko planoan erakutsiko den aukerako irudi bat</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="289"/>
      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
      <translation>Hau markatuta badago, estilo-orri bat adierazi bada hobespen orokorretan, hura erabiliko da eta hemengo koloreak gainidatziko dira</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="308"/>
      <source>Page background color</source>
      <translation>Orriaren atzeko planoaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="321"/>
      <source>The color of the text on the main pages</source>
      <translation>Orri nagusien testuaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="341"/>
      <source>Background image</source>
      <translation>Atzeko planoko irudia</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="348"/>
      <source>Page text color</source>
      <translation>Orriko testuaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="361"/>
      <source>The color of the links</source>
      <translation>Esteken kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="387"/>
      <source>The background color of the boxes inside the pages</source>
      <translation>Orri barruko kutxen atzeko planoaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="407"/>
      <source>Box background color</source>
      <translation>Kutxen atzeko planoaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="420"/>
      <source>The background color behind the panels</source>
      <translation>Panelen atzeko planoaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="449"/>
      <source>The down gradient for the background color (currently unsupported)</source>
      <translation>Atzeko planoaren kolorearen beheranzko gradientea (momentuz ez da onartzen)</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="472"/>
      <source>Open links</source>
      <translation>Ireki estekak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="479"/>
      <source>Background text color</source>
      <translation>Atzeko planoko testuaren kolorea</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="486"/>
      <source>Use FreeCAD style sheet</source>
      <translation>Erabili FreeCADen estilo-orria</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="493"/>
      <source>Font family</source>
      <translation>Letra-tipoa</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="502"/>
      <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
      <translation>Hasierako orrian erabiliko den letra-tipoa. Letra-tipo baten izena izan daiteke, edo komaz banandutako ordezko letra-tipoen izenak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="508"/>
      <source>Arial,Helvetica,sans</source>
      <translation>Arial,Helvetica,sans</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="521"/>
      <source>The base font size to use for all texts of the Start page</source>
      <translation>Hasierako orriko testu guztiek erabiliko duten oinarrizko letra-tamaina</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="524"/>
      <source>px</source>
      <translation>px</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="542"/>
      <source>Use gradient for New File icon</source>
      <translation>Erabili gradientea 'Fitxategi berria' ikonorako</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="568"/>
      <source>Options</source>
      <translation>Aukerak</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="577"/>
      <source>Should the start page be closed after loading?</source>
      <translation>Hasierako orria itxi beharko litzateke kargaren ondoren?</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="596"/>
      <source>Switch workbench after loading</source>
      <translation>Txandakatu lan-mahaia kargaren ondoren</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="603"/>
      <source>Close start page after loading</source>
      <translation>Itxi hasierako orria kargaren ondoren</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="610"/>
      <source>Close &amp; switch on file open</source>
      <translation>Itxi eta txandakatu fitxategia irekitzean</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="617"/>
      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
      <translation>FreeCAD fitxategi bat irekita hasten bada, aplikatu goiko bi ezarpenak</translation>
    </message>
  </context>
</TS>
